asr.test.mocks.gpaw.utilities.ibz2bz
====================================

.. automodule:: asr.test.mocks.gpaw.utilities.ibz2bz

   
   
   .. rubric:: Functions

   
   .. autofunction:: ibz2bz
   
   

   
   
   

   
   
   